@@ -7,9 +7,9 @@
 #ifndef KPACKAGE_PACKAGE_H
 #define KPACKAGE_PACKAGE_H
 
-#include <QStringList>
-#include <QMetaType>
 #include <QCryptographicHash>
+#include <QMetaType>
+#include <QStringList>
 #include <QUrl>
 
 #include <KPluginMetaData>
@@ -20,7 +20,6 @@
 
 namespace KPackage
 {
-
 /**
  * @class Package kpackage/package.h <KPackage/Package>
  *
@@ -59,7 +58,7 @@ namespace KPackage
  *      virtual install and uninstall methods
  *    * subclasses can be compiled as plugins for easy re-use
  **/
-//TODO: write documentation on USING a package
+// TODO: write documentation on USING a package
 
 class PackagePrivate;
 class PackageStructure;
@@ -85,7 +84,7 @@ public:
         PackageAlreadyInstalledError, /**< The package is already installed and a normal install (not update) was performed */
         PackageMoveError, /**< Failure to move a package from the system temporary folder to its final destination */
         PackageCopyError, /**< Failure to copy a package folder from somewhere in the filesystem to its final destination */
-        PackageUninstallError /**< Failure to uninstall a package */
+        PackageUninstallError, /**< Failure to uninstall a package */
     };
 
     /**
@@ -208,8 +207,8 @@ public:
     bool allowExternalPaths() const;
 
     /**
-      * @return the package metadata object.
-      */
+     * @return the package metadata object.
+     */
     KPluginMetaData metadata() const;
 
 #if KPACKAGE_ENABLE_DEPRECATED_SINCE(5, 21)
@@ -391,4 +390,3 @@ private:
 
 Q_DECLARE_METATYPE(KPackage::Package)
 #endif
-
